Crate chunked_quote_impl

Crate chunked_quote_impl 

Macros

chunk
append to TokenStream code generating the input tokens.
chunk_spanned
chunk but with specified span for all tokens not interpolated.
quote
create a TokenStream from the input tokens.
quote_spanned
quote! but with specified span for all tokens not interpolated.