Macros
- chunk
- append to
TokenStreamcode generating the input tokens. - chunk_
spanned chunkbut with specified span for all tokens not interpolated.
TokenStream code generating the input tokens.chunk but with specified span for all tokens not interpolated.